function initGame()
  falcon = {}
  falcon.x = 0
  falcon.y = 0
  falcon.yv = 0
  falcon.myv = 0

  phase = "setup"

  groundY = 601

  distance = love.math.random(3750000,5500000)
  startingDistance = distance
  time = distance/125000

  stars = {}

  falconImg = love.graphics.newImage("img/falcon.png")
  landingImg = love.graphics.newImage("img/landing.png")

  overlayImg = love.graphics.newImage("img/overlay.png")

  debris = {}
  debris[1] = {img=love.graphics.newImage("img/debris/bomb.png"),width=50,height=95}
  debris[2] = {img=love.graphics.newImage("img/debris/rock.png"),width=114,height=67}

  winSound = love.audio.newSource("sfx/land.mp3")
  failSound = love.audio.newSource("sfx/fail.mp3")

  for i = 1, 2000 do
    stars[i] = {x=love.math.random(1,800),y=love.math.random(1,600),layer=love.math.random(2,20)}
  end

  d = {}

  for i = 0,0 do
    d[i] = {x=love.math.random(100,500),y=love.math.random(1000,25000),type=love.math.random(1,#debris)}
  end

  e = {}
  explosionImg = love.graphics.newImage("img/explosion.png")

  people = {}
  for i = 1, 40 do
    people[i] = { x = love.math.random(30,750),y = love.math.random(330,550),xv = 0}
  end
  personImg = love.graphics.newImage("img/person.png")

  msg = "BREAKING NEWS, LIVE: Elon Musk attempts to LAND Falcon to secure funds for Mars colony!"
end

function drawGame()
  for i = 1, #stars do
    love.graphics.setColor(255,255,255,255/stars[i].layer)
    love.graphics.rectangle("fill",stars[i].x,stars[i].y,2,2)
  end

    love.graphics.setColor(255,255,255,200)
  for i = 1, #d do
    love.graphics.draw(debris[d[i].type].img,d[i].x,d[i].y)
  end
    --  love.graphics.setColor(0,100,0)
  --  love.graphics.rectangle("fill",0,groundY,800,800000)
  love.graphics.setColor(255,255,255,255)
  love.graphics.draw(landingImg,0,groundY)
  for i = 1, #people do
    love.graphics.draw(personImg,people[i].x,people[i].y+groundY)
  end

  love.graphics.setColor(255,(1000/falcon.yv)*255,(1000/falcon.yv)*255)
  love.graphics.draw(falconImg,falcon.x,falcon.y)

  love.graphics.setColor(255,255,255,255)
  for i = 1, #e do
    love.graphics.draw(explosionImg,e[i].x,e[i].y)
  end

  local now = os.date("*t")

  if distance < 2000000 and falcon.yv > 1500 then
    love.graphics.setColor(255,0,0)
    love.graphics.setFont(bFont)
    love.graphics.printf("!! SLOW DOWN !!",0,200,800,"center")

    love.graphics.setFont(font)
  end
  love.graphics.draw(overlayImg)
  love.graphics.printf(now.hour..":"..now.min,58,64,68,"center")
  love.graphics.setFont(mFont)
  love.graphics.printf(round(time).."s",687,43,58,"center")
  love.graphics.rectangle("line",687,70,58,24)
  love.graphics.rectangle("fill",687,70,58*(distance/startingDistance),24)
  love.graphics.printf(round(falcon.yv).."\nmph",690,511,78,"center")

  love.graphics.setFont(font)

  --love.graphics.setColor(0,0,0,150)
--  love.graphics.rectangle("fill",0,0,800,12)
--  love.graphics.setColor(255,255,255,255)
  --love.graphics.print("Velocity: "..round(falcon.yv).."mph, current minimum: "..round(falcon.myv/4).."mph, distance: "..round(distance).."m, time remaining: "..round(time).."s")

  love.graphics.setColor(255,0,0)
  love.graphics.rectangle("fill",0,570,800,30)
  love.graphics.setColor(0,0,0)
  love.graphics.printf(msg,0,570,800,"center")
  if phase == "setup" then
    love.graphics.setColor(0,0,0,200)
    love.graphics.rectangle("fill",0,190,800,200)
    love.graphics.setColor(255,255,255,255)
    love.graphics.setFont(bFont)
    love.graphics.printf("Setup",0,200,800,"center")
    love.graphics.setFont(font)
    love.graphics.printf("You have "..round(time).."s to fall "..distance.."m.\nYou must land within 50m of the landing pad at a speed lower than 1500mph.\n\nPress enter to begin descent...",0,280,800,"center")

  elseif phase == "fail" then
    love.graphics.setColor(0,0,0,200)
    love.graphics.rectangle("fill",0,190,800,120)
    love.graphics.setColor(255,0,0)
    love.graphics.setFont(bFont)
    love.graphics.printf("FAIL",0,200,800,"center")

    love.graphics.setFont(font)
    love.graphics.printf("Press enter to continue...",0,280,800,"center")

  elseif phase == "success" then
    love.graphics.setColor(0,0,0,200)
    love.graphics.rectangle("fill",0,190,800,120)
    love.graphics.setColor(0,255,0)
    love.graphics.setFont(bFont)
    love.graphics.printf("SUCCESS!",0,200,800,"center")

    love.graphics.setFont(font)
    love.graphics.printf("Press enter to continue...",0,280,800,"center")

    love.graphics.setFont(font)
  end

end

function updateGame(dt)
  for i = 1, #stars do
    stars[i].y = stars[i].y - (falcon.yv/stars[i].layer)/2*dt
    if stars[i].y < 0 then stars[i].y = love.math.random(600,700)   stars[i].x = love.math.random(1,800) end
  end

  for i = 1, #d do
    d[i].y = d[i].y - (falcon.yv/2)*dt
  end

  cx,cy = love.mouse.getPosition( )
  if phase == "setup" then
    if love.keyboard.isDown("return") then
      phase = "play"
    end
  elseif distance > 0 then
    time = time - 1*dt

    if time < 0 then
      phase = "fail"
      distance = -1
    end

    falcon.x = falcon.x + ((cx-60)-falcon.x)/15
    falcon.y = falcon.y + ((cy-240)-falcon.y)/15
    falcon.yv = falcon.yv + (falcon.y-50)*dt
    if falcon.myv < falcon.yv then falcon.myv = falcon.yv end
    if falcon.yv < falcon.myv/4 then
      falcon.yv = falcon.myv/4
    end

    distance = distance - falcon.yv

    if falcon.yv > 1500 then msg = "The ship needs to SLOW DOWN if it's going to stand a chance of landing!" end
    if falcon.myv/4 > 1500 then msg = "TOO FAST ELON! Clear the landing site, this thing is going to blow!!" end
  elseif phase == "play" then
    if falcon.yv > 255500 then
      phase = "fail"
      distance = -1
    end
    distance = 0
    groundY = groundY - 100*dt
    falcon.yv = falcon.yv - falcon.yv/1.5*dt
    if falcon.y > 125 then falcon.y = falcon.y - (falcon.yv/8)*dt
    elseif falcon.y < 125 then falcon.y = falcon.y + (falcon.yv/8)*dt end
    if groundY < 0 then groundY = 0  if distanceFrom(falcon.x,falcon.y,324,125) > 50 or time < 0 then msg = "Oof, that was embarrasing..." love.audio.play(failSound) phase = "fail" else phase = "success" msg = "THE MAD MAN HAS DONE IT!!!" love.audio.play(winSound) end end
    local perDown = math.abs(((groundY-600)/600))
    love.graphics.setBackgroundColor(100*perDown,100*perDown,255*perDown)

    --make people move away from the landing position of the ship
    for i = 1, #people do
      if groundY < 200 and math.abs(falcon.x-people[i].x) < 200 and people[i].xv == 0 then
        people[i].xv = love.math.random(-200,200)
      elseif math.abs(falcon.x-people[i].x) > 200 then
        people[i].xv = 0
      end

      people[i].x = people[i].x + people[i].xv*dt
    end

  elseif phase == "fail" then
    if love.math.random(1,2) == 1 then
      local i = #e+1
      e[i] = {}
      e[i].x = love.math.random(falcon.x-50,falcon.x+100)
      e[i].y = love.math.random(falcon.y-100,falcon.y+266)
      e[i].xv = 0
      e[i].yv = -falcon.yv
    end

    for i = 1, #people do
      if people[i].xv == 0 then
        people[i].xv = love.math.random(-250,250)
      end
      people[i].x = people[i].x + people[i].xv*dt
    end

    for i = 1, #e do
      e[i].x = e[i].x + e[i].xv*dt
      e[i].y = e[i].y + e[i].yv*dt
    end

    if love.keyboard.isDown("return") then
      initGame()
      love.graphics.setBackgroundColor(0,0,0)
      phase = "setup"
    end
  elseif phase == "success" then
    if love.keyboard.isDown("return") then
      game_state = "intro"
      love.graphics.setBackgroundColor(0,0,0)
      initGame()
      intro.stage = 6
    end
  end

end
